/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.javagnome.Handle;

/**
 * 
 */
public class CellRendererProgress extends CellRenderer {

	public CellRendererProgress() {
		super(gtk_cell_renderer_progress_new());
	}

	native static final protected int gtk_cell_renderer_progress_get_type();
	native static final protected Handle gtk_cell_renderer_progress_new();

}
